;; Generated package description from taxy-magit-section.el  -*- no-byte-compile: t -*-
(define-package "taxy-magit-section" "0.13.0.20240124.3519" "View Taxy structs in a Magit Section buffer" '((emacs "26.3") (magit-section "3.2.1") (taxy "0.10")) :commit "9d79793edaa98a8a06674723ad5a53ebc4fc237c" :authors '(("Adam Porter" . "adam@alphapapa.net")) :maintainer '("Adam Porter" . "adam@alphapapa.net") :keywords '("lisp") :url "https://github.com/alphapapa/taxy.el")
